@@ -33,20 +33,14 @@ LineEdit::LineEdit(LineEdit::TypeLineEdit type ,QGraphicsWidget *parent)
     setFlags(ItemIsFocusable);
 
     /* Add a background image */
-    createBackground();
-
-    /* Focus line */
-    createFocus();
+    _createBackground();
 
     /* The entry */
-    createEntry();
+    _createEntry();
 
     /* Entry widget' signals */
-//    connect(_entryWidget, SIGNAL(clicked()), this, SLOT(selectAll()));
-    connect(_entryWidget, SIGNAL(doubleClicked()), this, SLOT(selectAll()));
     connect(_entryWidget, SIGNAL(gainedFocus()), this, SLOT(gainedFocus()));
     connect(_entryWidget, SIGNAL(lostFocus()), this, SLOT(lostFocus()));
-//    connect(_entryWidget, SIGNAL(returnPressed()), this, SLOT(lostFocus()));
 }
 
 /*!
@@ -61,7 +55,6 @@ LineEdit::~LineEdit()
  */
 void LineEdit::setEchoMode(QLineEdit::EchoMode echo)
 {
-    _entryWidget = (LineEditBox *) _entry->widget();
     _entryWidget->setEchoMode(echo);
 }
 
@@ -94,10 +87,11 @@ void LineEdit::keyPressEvent(QKeyEvent *event)
         emit enterPressed();
 }
 
+
 /*!
  * \brief Creates the background image.
  */
-void LineEdit::createBackground(void)
+void LineEdit::_createBackground(void)
 {
     _image = new QGraphicsPixmapItem(this);
 
@@ -113,30 +107,14 @@ void LineEdit::createBackground(void)
     _image->setZValue(-1);
 }
 
-/*!
- * \brief Creates the focus outilne. By default,
- * the outline is not visible.
- */
-void LineEdit::createFocus(void)
-{
-    _focusLine = new FocusLine(_image->pixmap().width(), _image->pixmap().height()  , this);
-    _focusLine->setPos(0, 0);
-    _focusLine->setVisible(false);
-}
-
 /*!
  * \brief Creates the entry box. A QLineEdit object(QWidget)
  * is added to a QGraphicsProxyWidget.
  */
-void LineEdit::createEntry(void)
+void LineEdit::_createEntry(void)
 {
     /* Create a frameless transparent entry box */
     _entryWidget = new LineEditBox();
-    QPalette palette(_entryWidget->palette());
-    palette.setColor(_entryWidget->backgroundRole(), Qt::transparent);
-    palette.setColor(QPalette::Disabled, QPalette::Background, Qt::transparent);
-    palette.setBrush(QPalette::Disabled, QPalette::Text, Qt::black);
-    _entryWidget->setPalette(palette);
     _entryWidget->setAttribute(Qt::WA_NoSystemBackground);
     _entryWidget->setContextMenuPolicy(Qt::NoContextMenu);
     _entryWidget->setFrame(false);
@@ -159,17 +137,22 @@ void LineEdit::createEntry(void)
             _entryWidget->setGeometry(5, 15, 255, 32);
             break;
         case Long:
-            _entryWidget->setGeometry(50, 10, 572, 32);
+            _entryWidget->setGeometry(50, 15, 650, 32);
             _entryWidget->setMaxLength(1139);
-            createCounter();
+            _createCounter();
             break;
     }
+
+    connect(_entryWidget, SIGNAL(textChanged(QString)), SIGNAL(textChanged()));
+
+    if (_type == LineEdit::Long)
+        connect(_entryWidget, SIGNAL(textChanged(QString)), SLOT(_updateCounter()));
 }
 
 /*!
  * \brief Creates the counter for the long line edit
  */
-void LineEdit::createCounter(void)
+void LineEdit::_createCounter(void)
 {
     font.setBold(true);
     font.setPixelSize(16);
@@ -187,9 +170,9 @@ void LineEdit::createCounter(void)
  * \brief Gets the length of the text.
  * \return Text length
  */
-int LineEdit::getTextLength(void)
+QString LineEdit::getText(void)
 {
-    return _entryWidget->text().length();
+    return _entryWidget->text();
 }
 
 /*!
@@ -209,7 +192,6 @@ void LineEdit::selectAll(void)
     if (!_entryWidget->text().isEmpty()) {
         _entryWidget->selectAll();
     }
-
     _entryWidget->setFocus();
 }
 
@@ -220,7 +202,6 @@ void LineEdit::gainedFocus(void)
 {
     switch(_type){
         case Long:
-            _focusLine->setVisible(false);
             if(this->_entryWidget->text().length() > 140)
                 _image->setPixmap(QPixmap(":images/resources/textboxes/textbox_red.png"));
             else
@@ -228,7 +209,7 @@ void LineEdit::gainedFocus(void)
             break;
 
         case Short:
-            _focusLine->setVisible(true);
+            _image->setPixmap(QPixmap(":images/resources/textboxes/textbox-short_pressed.png"));
             break;
     }
     update();
@@ -239,7 +220,6 @@ void LineEdit::gainedFocus(void)
  */
 void LineEdit::lostFocus(void)
 {
-    _focusLine->setVisible(false);
     switch(_type){
         case Long:
             if(this->_entryWidget->text().length() > 140)
@@ -252,9 +232,6 @@ void LineEdit::lostFocus(void)
             _image->setPixmap(QPixmap(":images/resources/textboxes/textbox-short.png"));
             break;
     }
-
-    _entryWidget->deselect();
-    _entryWidget->clearFocus();
     update();
 }
 
@@ -268,8 +245,7 @@ void LineEdit::keyReleaseEvent(QKeyEvent *event)
 
     switch(_type){
         case Long:
-            updateCounter();
-
+            _updateCounter();
             if(this->_entryWidget->text().length() > 140)
                 _image->setPixmap(QPixmap(":images/resources/textboxes/textbox_red.png"));
             else
@@ -277,12 +253,14 @@ void LineEdit::keyReleaseEvent(QKeyEvent *event)
             break;
     }
     update();
+
+    emit textChanged();
 }
 
 /*!
  * \brief Update the counter message number for the long line edit
  */
-void LineEdit::updateCounter(void)
+void LineEdit::_updateCounter(void)
 {
     QFontMetrics fm(font);
     counter->setPlainText(QString::number(140 - this->_entryWidget->text().length()));
@@ -298,15 +276,35 @@ void LineEdit::setMessage(QString message)
 {
     _entryWidget->setText(message);
 
-
     switch(_type){
         case Long:
-            this->updateCounter();
             if(this->_entryWidget->text().length() > 140)
                 _image->setPixmap(QPixmap(":images/resources/textboxes/textbox_red.png"));
             else
                 _image->setPixmap(QPixmap(":images/resources/textboxes/textbox_pressed.png"));
             break;
+    }
+}
+
+/*!
+ * \brief This function enables or disables a line edit.
+ * \param option true to enable and false to disable line edit.
+ */
+void LineEdit::enable(bool option)
+{
+    this->setEnabled(option);
+
+    switch(_type){
+        case Short:
+            if(option)
+                _image->setPixmap(QPixmap(":images/resources/textboxes/textbox-short.png"));
+            else
+                _image->setPixmap(QPixmap(":images/resources/textboxes/textbox-short-disabled.png"));
             break;
     }
 }
+
+void LineEdit::setMaxLength(int length)
+{
+    _entryWidget->setMaxLength(length);
+}
