@@ -23,61 +23,11 @@
 #ifndef LINEEDIT_H
 #define LINEEDIT_H
 
-#include <QtCore/QRectF>
-#include <QtCore/QObject>
-#include <QtCore/QString>
-
 #include <QtGui/QLineEdit>
-#include <QtGui/QFont>
-#include <QtGui/QGraphicsPixmapItem>
-#include <QtGui/QGraphicsPathItem>
 #include <QtGui/QGraphicsProxyWidget>
-#include <QtGui/QGraphicsSceneMouseEvent>
-#include <QtGui/QPainter>
-#include <QtGui/QPalette>
-#include <QtGui/QPainterPath>
-#include <QtGui/QPixmap>
 
 #include "twitterapplicationitem.h"
 
-/*!
- * \class FocusLine
- *
- * \brief Creates an outline for a focused object.
- */
-class FocusLine : public QGraphicsPathItem
-{
-
-public:
-    FocusLine(int width, int height, QGraphicsItem *parent = 0)
-            : QGraphicsPathItem(parent) {
-        QPen pen;
-        pen.setWidth(3);
-        pen.setBrush(QColor(15, 149, 218));
-        pen.setCapStyle(Qt::RoundCap);
-        pen.setJoinStyle(Qt::RoundJoin);
-
-        QPainterPath path;
-        path.addRoundedRect(0, 0, width, height, 3, 3);
-
-        setPen(pen);
-        setBrush(Qt::NoBrush);
-        setPath(path);
-    }
-
-    ~FocusLine() {
-    }
-
-    void paint(QPainter *painter,
-               const QStyleOptionGraphicsItem *option,
-               QWidget * widget) {
-        painter->setRenderHint(QPainter::Antialiasing);
-
-        QGraphicsPathItem::paint(painter, option, widget);
-    }
-
-};
-
 /*!
  * \class LineEditBox
  *
@@ -97,11 +47,6 @@ public:
     }
 
 protected:
-    void mouseDoubleClickEvent(QMouseEvent *event) {
-        Q_UNUSED(event);
-        emit doubleClicked();
-    }
-
     void focusInEvent(QFocusEvent *event) {
         QLineEdit::focusInEvent(event);
         emit gainedFocus();
@@ -113,10 +58,8 @@ protected:
     }
 
 signals:
-    void clicked(void);
     void gainedFocus(void);
     void lostFocus(void);
-    void doubleClicked(void);
 };
 
 /*!
@@ -134,30 +77,17 @@ public:
 
     LineEdit(LineEdit::TypeLineEdit type , QGraphicsWidget *parent = 0);
     ~LineEdit();
-
     void setEchoMode(QLineEdit::EchoMode echo);
-    void mousePressEvent(QGraphicsSceneMouseEvent *event);
-    void mouseDoubleClickEvent(QGraphicsSceneMouseEvent *event);
-    void keyPressEvent(QKeyEvent *event);
-    void createBackground(void);
-    void createFocus(void);
-    void createEntry(void);
-    void createCounter(void);
-    void setMessage(QString);
-    int getTextLength(void);
-
+    void setMessage(QString message);
+    QString getText(void);
     QGraphicsProxyWidget *getEntry(void);
+    void enable(bool option);
+    void setMaxLength(int length);
 
     QRectF boundingRect() const {
         return _image->boundingRect();
     }
 
-    QPainterPath shape() const {
-        QPainterPath path;
-        path.addRoundedRect(boundingRect(), 25, 25);
-        return path;
-    }
-
 public slots:
     void selectAll(void);
     void gainedFocus(void);
@@ -165,18 +95,26 @@ public slots:
 
 signals:
     void enterPressed(void);
+    void textChanged(void);
 
 private:
-    void updateCounter(void);
+    void _createCounter(void);
+    void _createBackground(void);
+    void _createEntry(void);
+
+private slots:
+    void _updateCounter(void);
 
 protected:
-    void keyReleaseEvent(QKeyEvent *event);
+    virtual void keyReleaseEvent(QKeyEvent *event);
+    virtual void mousePressEvent(QGraphicsSceneMouseEvent *event);
+    virtual void mouseDoubleClickEvent(QGraphicsSceneMouseEvent *event);
+    virtual void keyPressEvent(QKeyEvent *event);
 
 private:
     QGraphicsPixmapItem *_image;
-    FocusLine *_focusLine;
     QGraphicsProxyWidget *_entry;
-    LineEditBox *_entryWidget;
+    QLineEdit *_entryWidget;
     int _type;
     QGraphicsTextItem *counter;
     QFont font;
