@@ -23,16 +23,9 @@
 #ifndef LOADER_H
 #define LOADER_H
 
-#include <QtCore/QDebug>
-#include <QtCore/QObject>
 #include <QtCore/QParallelAnimationGroup>
 #include <QtCore/QPropertyAnimation>
 
-#include <QtGui/QPainter>
-#include <QtGui/QGraphicsPixmapItem>
-#include <QtGui/QGraphicsRectItem>
-
-
 #include "twitterapplicationitem.h"
 
 /*!
@@ -63,6 +56,9 @@ private:
 signals:
     void finished(void);
 
+protected:
+    void mousePressEvent(QGraphicsSceneMouseEvent *event);
+
 public slots:
     void startEntryAnimation(void);
     void startExitAnimation(void);
