@@ -24,43 +24,30 @@
 
 /*!
  * \brief Class Constructor
- * \param username The username
- * \param text The tweet message
- * \param imageUrl The user's avatar url
- * \param statusId The tweet id
- * \param createdAt When the tweet was created
- * \param source Which app was used when creating the message
- * \param favorite If the tweet is favorite
- * \param coordinates Coordinates where the tweet was made
- * \param isMyTweet If the tweet belongs to the user
- * \param posInList The tweet position in the list
- * \param parent the Tweet parent
+ * \param entry object with all the tweet's informations
  */
-Tweet::Tweet(const QString &username, const QString &text, const QString &imageUrl, const QString &statusId,
-             const QString &createdAt, const QString &source, const bool &favorite, const QString &coordinates,
-             bool isMyTweet, int posInList, QGraphicsWidget *parent)
+Tweet::Tweet(Entry entry, QGraphicsWidget *parent)
     : TwitterApplicationItem(parent),
-    m_username(username)
+    m_entry(entry),
+    m_image(QImage(":images/resources/avatar.png"))
 {
     paintImage = false;
     this->setMinimumSize(776,74);
 
-    m_username = username;
-    m_text = text;
-    m_imageUrl = imageUrl;
-    m_statusId = statusId;
-    m_source = source;
-    m_createdAt = createdAt;
-    m_favorite = favorite;
-    m_coordinates = coordinates;
-    m_isMyTweet = isMyTweet;
-    m_posInList = posInList;
-    m_following = true;
+    createTweetMessage();
 
-    createTweetMessage(m_username, parseText(m_text), parseCreatedAt(createdAt), parseSource(m_source));
+    if(m_entry.favorited) {
+        m_favorited = new QGraphicsPixmapItem(QPixmap::fromImage(QImage(":images/resources/fave_ico.png")),this);
+        m_favorited->setPos(768,5);
+    }
+
+    if(m_entry.text.contains("RT")) {
+        m_rtImage = new QGraphicsPixmapItem(QPixmap::fromImage(QImage(":images/resources/rt_timeline.png")),this);
+        m_rtImage->setPos(77,9);
+    }
 
     connect(&m_manager, SIGNAL(finished(QNetworkReply*)), this, SLOT(handleNetworkRequest(QNetworkReply*)));
-    download(imageUrl);
+    download(m_entry.userInfo.imageUrl);
 }
 
 /*!
@@ -84,25 +71,25 @@ void Tweet::mouseReleaseEvent(QGraphicsSceneMouseEvent *event)
 
 /*!
  * \brief Writes The whole tweet message
- * \param username The user that made the tweet
- * \param text The tweet message
- * \param creatAt Information about the time of the tweet
- * \param source Information about the origin of the tweet
+ * \param entry
  */
-void Tweet::createTweetMessage(QString username, QString text, QString creatAt, QString source)
+void Tweet::createTweetMessage()
 {
     QString messageHtml = "<p style=\" font-size:18px; padding-bottom:0px; margin-bottom:0px; font-family:'Nokia Sans';\"> ";
-    messageHtml += "<span style=\" color:#0f95da;\">" + username + "</span>";
-    messageHtml += "<span style=\" color:#000000;\"> " + text + "</span>";
-    messageHtml += "</p>";
+    if(m_entry.text.contains("RT"))
+        messageHtml += "<span style=\" color:#0f95da;\">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;" + m_entry.userInfo.screenName + "</span>";
+    else
+        messageHtml += "<span style=\" color:#0f95da;\">" + m_entry.userInfo.screenName + "</span>";
+    messageHtml += "<span style=\" color:#000000;\"> " + parseText(m_entry.originalText) + "</span></p>";
 
     QString messageInfo = "<p align=\"right\"; style=\" padding-top:5px; margin-top:5px; font-size:14px; font-family:'Nokia Sans';\"> ";
-    messageInfo += "<span style=\" color=#757575;\">" + creatAt + " via " + source + "</span>";
-    messageInfo += "</p>";
+    messageInfo += "<span style=\" color=#757575;\">" + parseCreatedAt(m_entry.localTime);
+    messageInfo += " via " + parseSource(m_entry.source) + "</span></p>";
 
     message = new QGraphicsTextItem(this);
     message->setPos(74,0);
     message->setTextWidth(702);
+    message->setDefaultTextColor(QColor(0,0,0));
     message->setHtml(messageHtml + messageInfo);
 
     if(message->document()->size().height() < 56) {
@@ -110,8 +97,14 @@ void Tweet::createTweetMessage(QString username, QString text, QString creatAt,
         message->setHtml(messageHtml + messageInfo);
     }
 
+    if (m_entry.hasInReplyToStatusId) {
+        messageInfo.replace("</span></p>"," in reply to " + m_entry.inReplyToScreenName + "</span></p>");
+        message->setHtml(messageHtml + messageInfo);
+    }
+
     if(message->document()->size().height() > 74)
-        this->setMinimumHeight(message->document()->size().height());
+        setMinimumHeight(message->document()->size().height());
+    setMaximumHeight(this->minimumHeight());
 }
 
 /*!
@@ -123,7 +116,6 @@ void Tweet::download(QString Url)
     QNetworkRequest request;
     request.setUrl(Url);
     m_manager.get(request);
-
 }
 
 /*!
@@ -138,7 +130,6 @@ void Tweet::handleNetworkRequest(QNetworkReply *reply)
     emit imageDownloaded();
 
     reply->deleteLater();
-    paintImage = true;
     update();
 }
 
@@ -151,24 +142,19 @@ void Tweet::paint(QPainter *painter, const QStyleOptionGraphicsItem *option, QWi
     Q_UNUSED(option);
     Q_UNUSED(widget);
 
-    QPointF origin = rect().topLeft();
-
     // Transparent Rect
     painter->setPen(Qt::NoPen);
 
-    if(m_isMyTweet)
+    if(m_entry.isOwn)
         painter->setBrush(QColor(255, 240, 204));
     else
         painter->setBrush(QColor(246, 253, 255));
 
-    painter->drawRoundedRect(origin.x(), origin.y(), rect().width(), (origin.y() + rect().height()), 2, 2);
+    painter->drawRoundedRect(0, 0, rect().width(), rect().height(),2,2);
+    painter->setRenderHint(QPainter::Antialiasing);
 
     // Avatar Rect
-    painter->setBrush(Qt::white);
-    if(paintImage)
-        painter->drawImage(QRect(13,(this->boundingRect().height() - 48)/2,48,48),m_image);
-    else
-        painter->drawRect(13,(this->boundingRect().height() - 48)/2,51,51);
+    painter->drawImage(QRect(13,13,48,48),m_image);
 }
 
 /*!
@@ -186,17 +172,15 @@ QString Tweet::parseSource(QString source)
  * \param source The list with the time of the tweets
  * \return A list with only the time of the tweets
  */
-QString Tweet::parseCreatedAt(QString createdAt)
+QString Tweet::parseCreatedAt(QDateTime timestamp)
 {
-    createdAt.remove(QRegExp("\\+0{4} "));
-    QDateTime tweetDate = QDateTime::fromString(createdAt,"ddd MMM dd HH:mm:ss yyyy");
-    tweetDate.setTimeSpec(Qt::UTC);
+    QLocale::setDefault(QLocale::English);
 
     QString newCreatedAt;
-    int seconds = tweetDate.toUTC().secsTo(QDateTime::currentDateTime().toUTC());
+    int seconds = timestamp.secsTo(QDateTime::currentDateTime().toUTC());
 
     if (seconds < 20) {
-        newCreatedAt = "Less than " + QString::number(seconds) + " seconds ago";
+        newCreatedAt = "Less than 20 seconds ago";
     } else if(seconds < 30) {
         newCreatedAt = "About half minute ago";
     } else if(seconds < 60) {
@@ -208,12 +192,12 @@ QString Tweet::parseCreatedAt(QString createdAt)
     } else if(seconds < 86400) {
         newCreatedAt = "About " + QString::number(seconds/3600) + " hours ago";
     } else {
-        newCreatedAt = QString::number(tweetDate.time().hour()) + ":" +
-                       QString::number(tweetDate.time().minute()) + " " +
-                       QDate::shortMonthName(tweetDate.date().month()) + " " +
-                       QString::number(tweetDate.date().day());
+        newCreatedAt = QString::number(timestamp.time().hour()) + ":" +
+                       QString::number(timestamp.time().minute()) + " " +
+                       QDate::shortMonthName(timestamp.date().month()) + " " +
+                       QString::number(timestamp.date().day());
 
-        switch(tweetDate.date().day()) {
+        switch(timestamp.date().day()) {
             case 1:
             case 21:
                 newCreatedAt += "st "; break;
@@ -251,24 +235,6 @@ QString Tweet::parseText(QString text)
     return text;
 }
 
-/*!
- * \brief Method to get the username from tweet
- * \return The username
- */
-QString Tweet::getUsername(void)
-{
-    return this->m_username;
-}
-
-/*!
- * \brief Method to get the tweet's message from tweet
- * \return The message
- */
-QString Tweet::getMessage(void)
-{
-    return this->m_text;
-}
-
 /*!
  * \brief Method to get the avatar's image from tweet
  * \return The avatar image
@@ -278,48 +244,13 @@ QImage Tweet::getImage(void)
     return this->m_image;
 }
 
-/*!
- * \brief Method to get the tweet's id from tweet
- * \return The tweet's id
- */
-QString Tweet::getStatusId(void)
-{
-    return this->m_statusId;
-}
-
-/*!
- * \brief Method to get the favorite flag from tweet
- * \return The favorite flag
- */
-bool Tweet::getFavorite(void)
-{
-    return this->m_favorite;
-}
-
-/*!
- * \brief Method to get the tweet's coordinates from tweet
- * \return The tweet's coordinates
- */
-QString Tweet::getCoordinates(void)
-{
-    return this->m_coordinates;
-}
-
-/*!
- * \brief Method to get the tweet's ownership flag
- * \return The tweet's ownership flag
- */
-bool Tweet::getIsMyTweet(void)
-{
-    return this->m_isMyTweet;
-}
 /*!
  * \brief Method to get the tweet's position in the list from tweet
  * \return The tweet's position
  */
 int Tweet::getPosInList(void)
 {
-    return this->m_posInList;
+//    return this->m_posInList;
 }
 
 /*!
@@ -328,7 +259,7 @@ int Tweet::getPosInList(void)
  */
 bool Tweet::getFollowing(void)
 {
-    return this->m_following;
+//    return this->m_following;
 }
 
 /*!
@@ -347,8 +278,8 @@ QTextDocument* Tweet::getTweetDocument()
  */
 void Tweet::setFollowing(QString username, bool follow)
 {
-    if(m_username == username)
-        m_following = follow;
+//    if(m_username == username)
+//        m_following = follow;
 }
 
 /*!
@@ -357,7 +288,7 @@ void Tweet::setFollowing(QString username, bool follow)
  */
 void Tweet::setFavorite(bool favorite)
 {
-    this->m_favorite = favorite;
+//    this->m_favorite = favorite;
 }
 
 /*!
@@ -366,5 +297,10 @@ void Tweet::setFavorite(bool favorite)
  */
 void Tweet::setPosition(int position)
 {
-    m_posInList = position;
+//    m_posInList = position;
+}
+
+Entry Tweet::getEntry(void)
+{
+    return m_entry;
 }
