@@ -23,15 +23,11 @@
 #ifndef TWITTERBUTTON_H
 #define TWITTERBUTTON_H
 
-#include <QtCore/QObject>
-#include <QtCore/QRectF>
-#include <QtCore/QString>
-
 #include <QtGui/QStyleOptionGraphicsItem>
 #include <QtGui/QGraphicsSceneMouseEvent>
-#include <QtGui/QPixmap>
 #include <QtGui/QPainter>
-#include <QtGui/QPainterPath>
+
+#include <QtDBus>
 
 #include "twitterapplicationitem.h"
 
@@ -44,21 +40,26 @@ class TwitterButton : public TwitterApplicationItem
     Q_OBJECT
 
 public:
-    enum ButtonType { Update, Expose, Logout, Generic, Retweet, Reply, Favorite, NoFavorite, GoUrl, Delete, Back, Tab, More };
+    enum ButtonType { Expose, Logout, Generic, Retweet, Reply, Refresh,
+                      Favorite, NoFavorite, GoUrl, Delete, Back,
+                      Close, More, LoginSettings, GenericDownLeft,
+                      GenericDownRight, NewAccount };
 
     TwitterButton(ButtonType buttonType, QString buttonLabel, QGraphicsWidget *parent);
-    QPainterPath shape() const;
     QRectF boundingRect() const;
     void paint(QPainter *painter, const QStyleOptionGraphicsItem *option, QWidget *);
-    void enable(bool);
     void setTypeButton(int);
     void setLabel(QString);
-    void setUrl(QString);
 
 signals:
-    void pressed();
-    void released();
-    void released(QString);
+    void pressed(void);
+    void released(void);
+
+public slots:
+    void enable(bool);
+
+private slots:
+    void _emitExposeSignal(void);
 
 protected:
     virtual void mousePressEvent(QGraphicsSceneMouseEvent *);
