@@ -23,19 +23,13 @@
 #ifndef TWITTERTOPBAR_H
 #define TWITTERTOPBAR_H
 
-#include <QtCore/QObject>
-#include <QtCore/QRectF>
-#include <QtCore/QString>
-
-#include <QtGui/QStyleOptionGraphicsItem>
-#include <QtGui/QGraphicsSceneMouseEvent>
-#include <QtNetwork>
-#include <QtGui/QPixmap>
-#include <QtGui/QPainter>
-#include <QtGui/QPainterPath>
 #include <QtGui/QFileDialog>
 
+#include <QtNetwork>
+
 #include "twitterapplicationitem.h"
+#include "twitterbutton.h"
+#include "kineticlist.h"
 #include "backend.h"
 
 /*! \class TwitterTopBar
@@ -48,36 +42,43 @@ class TwitterTopBar : public TwitterApplicationItem
 
 public:
     TwitterTopBar(QGraphicsWidget *parent);
-    ~TwitterTopBar(void);
-    void paint(QPainter *painter, const QStyleOptionGraphicsItem *option, QWidget *);
-    QString getUsername();
 
 private slots:
     void _handleNetworkRequest(QNetworkReply *reply);
-    void _download(QString Url);
+    void _download(QString url);
     void _positions(void);
 
 signals:
     void finished(void);
     void changeAvatar(QString);
+    void settings(void);
+    void refresh(void);
 
 private:
+    void paint(QPainter *painter, const QStyleOptionGraphicsItem *option, QWidget *);
+    void saveImage(void);
+
+private:
+    QGraphicsTextItem *_name;
+    QRectF *_rect;
     QNetworkAccessManager m_manager;
-    QStringList list;
     QList<QPointF> listPositions;
-    QImage m_image;
-    QImage bgImage;
-    QImage followingNameImage;
-    QImage followersNameImage;
-    QImage tweetsNameImage;
-    QString followingText;
-    QString followersText;
-    QString tweetsText;
-    bool paintImage;
-    bool createTimeline;
+    QImage defaultAvatar;
+    QImage m_avatar;
+    QImage followingImage;
+    QImage followersImage;
+    QImage tweetsImage;
+    TwitterButton *_refreshButton;
+    TwitterButton *_homeButton;
+    TwitterButton *_mentionsButton;
+    KineticList *_buttonsList;
+    UserInfo user;
+    QFont font;
+    QString _imageUrl;
+    QGraphicsPixmapItem *m_settingsIco;
 
 public slots:
-    void updateTopBar(bool timeline);
+    void updateTopBar();
 
 protected:
     void mousePressEvent(QGraphicsSceneMouseEvent *event);
