@@ -23,16 +23,19 @@
 #ifndef TIMELINECTRL_H
 #define TIMELINECTRL_H
 
-#include <QtCore/QObject>
-#include <QtGui/QGraphicsProxyWidget>
 #include <QtGui/QGraphicsScene>
 
+#include "twitterapi/entry.h"
 #include "timelineview.h"
 #include "backend.h"
-#include "applicationItems/dialog.h"
 
-#include <QMaemo5InformationBox>
-#include <QAbstractKineticScroller>
+#include "applicationItems/dialog.h"
+#include "applicationItems/tweet.h"
+
+#ifdef Q_WS_MAEMO_5
+    #include <QMaemo5InformationBox>
+    #include <QAbstractKineticScroller>
+#endif
 
 /*! \class TimelineCtrl
  *
@@ -55,7 +58,7 @@ private slots:
     void _connectionError(QString);
     void _genericError(QString);
     void _handleFavorite(QString,bool);
-    void _handleDeleteTweet(QString, int);
+    void _handleDeleteTweet(quint64);
     void _logout(void);
     void _handleFriendship(QString, bool);
     void _updateWarning(QString);
@@ -64,17 +67,11 @@ private slots:
     void _updateProfileImage(QString);
     void _dialogLocation(void);
     void _handleGPSLocation(void);
-    void _addHomeTimelineToScene(StatusList *homeTimeline);
-    void _addMentionsTimelineToScene(StatusList *mentionsTimeline);
-    void _addDMTimelineToScene(StatusList *dmTimeline);
-    void _removeHomeTimelineFromScene(StatusList *homeTimeline);
-    void _removeMentionsTimelineFromScene(StatusList *mentionsTimeline);
-    void _removeDMTimelineFromScene(StatusList *dmTimeline);
-    void _moreTweetsToHome(StatusList *homeTimeline);
-    void _moreTweetsToMentions(StatusList *mentionsTimeline);
-
-private:
-    void _createListsScene(void);
+    void _populateTimeline(EntryList);
+    void _refreshTimeline(void);
+    void _moreTweets(void);
+    void _updatePosted(EntryList);
+    void _deletedTweet(quint64);
 
 private:
     QGraphicsScene *_scene;
@@ -82,8 +79,6 @@ private:
     QPropertyAnimation *_animInfo;
     QPropertyAnimation *_animLogoutButton;
     QPropertyAnimation *_animBackButton;
-    QEasingCurve easingCurve;
-    int animationDuration;
     bool atTimeline;
     bool isFollowing;
     bool updateTimeline;
@@ -96,6 +91,7 @@ private:
     bool addMentions;
     QGraphicsScene *m_scene;
     DialogView *dialog;
+    Tweet *_deleteTweet;
 };
 
 #endif // TIMELINECTRL_H
